import json
import math
import random
import sys
from pathlib import Path

# have Spiders test.json in the same dir as this script
# usage: python3 split-spider-test.py <path> <sample-number> <spilt-idx>
# writes full set to <path-without-dotjson>_orig.json if <path-without-dotjson>_orig.json is not present
# splits set in two parts, first part contains <sample-number> samples
# second part contains set-length - <number> samples
# first half is written to <path-without-dotjson>_p<split-idx>.json
# second half is written to <path>
#randomly picked sub sample of 10 % per database to:
# <same location>/sub_sampled_spider_test_set.json

# check number of args
if len(sys.argv) != 4:
  print("usage: python3 split-spider-test.py <path> <sample-number> <spilt-idx>", file=sys.stderr)
  exit(1)

# load input file
f = open(sys.argv[1])
data = json.load(f)
f.close()
print("Original length: " + str(len(data)))

# check sample number
sampleNumber = int(sys.argv[2])
if sampleNumber <= 0 or sampleNumber >= len(data):
  print("Number: " + str(sampleNumber) + " not in range: 1 to " + str(len(data)), file=sys.stderr)
  exit(1)

# check that file _p<split-idx> does not exists
splitIdx = int(sys.argv[3])
fp1str = sys.argv[1].replace(".json", "") + "_p" + str(splitIdx) + ".json"
fp1Path = Path(fp1str)
if fp1Path.exists():
  print("File: " + fp1str + " exists, please choose an index different from " + str(splitIdx))
  exit(1)

# save to _orig.json if not exists
forigstr = sys.argv[1].replace(".json", "") + "_orig.json"
forigPath = Path(forigstr)
if not forigPath.exists():
  forig = open(forigPath, "w")
  json.dump(data, fp=forig, indent=4)
  print("Written original data to: " + forigstr)

# split the data set, p1data containing sampleNumber many items
# p2data containing len(data) - sampleNumber many items
p1data = data[0:sampleNumber]
p2data = data[sampleNumber:]

# write p1data to file
fp1 = open(fp1str, "w")
json.dump(p1data, fp=fp1, indent=4)
fp1.close()
print("Written part 1 with " + str(len(p1data)) + " samples to: " + fp1str)

# write p2data to file
fp2 = open(sys.argv[1], "w")
json.dump(p2data, fp=fp2, indent=4)
fp2.close()
print("Written part 2 with " + str(len(p2data)) + " samples to: " + sys.argv[1])
print("Done.")
